@@ -5,7 +5,7 @@ This is used to test ability to detect and use custom modules.
 from ansible.module_utils.basic import AnsibleModule
 
 
-def main():
+def main() -> None:
     """Return the module instance."""
     return AnsibleModule(
         argument_spec=dict(
