@@ -3,11 +3,12 @@ import hashlib
 import json
 import os
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, Dict, Generic, List, TypeVar, Union
+from typing import TYPE_CHECKING, Any, Dict, Generic, List, Tuple, TypeVar, Union
 
 import rich
 
 from ansiblelint.config import options
+from ansiblelint.version import __version__
 
 if TYPE_CHECKING:
     from ansiblelint.errors import MatchError
@@ -32,36 +33,33 @@ class BaseFormatter(Generic[T]):
         if base_dir:  # can be None
             base_dir = base_dir.absolute()
 
-        # Required 'cause os.path.relpath() does not accept Path before 3.6
-        if isinstance(base_dir, Path):
-            base_dir = str(base_dir)  # Drop when Python 3.5 is no longer supported
-
         self._base_dir = base_dir if display_relative_path else None
 
-    def _format_path(self, path: Union[str, Path]) -> str:
-        # Required 'cause os.path.relpath() does not accept Path before 3.6
-        if isinstance(path, Path):
-            path = str(path)  # Drop when Python 3.5 is no longer supported
-
+    def _format_path(self, path: Union[str, Path]) -> Union[str, Path]:
         if not self._base_dir or not path:
             return path
         # Use os.path.relpath 'cause Path.relative_to() misbehaves
         return os.path.relpath(path, start=self._base_dir)
 
+    # pylint: disable=no-self-use
     def format(self, match: "MatchError") -> str:
+        """Format a match error."""
         return str(match)
 
-    def escape(self, text: str) -> str:
+    @staticmethod
+    def escape(text: str) -> str:
         """Escapes a string to avoid processing it as markup."""
         return rich.markup.escape(text)
 
 
 class Formatter(BaseFormatter):  # type: ignore
+    """Default output formatter of ansible-lint."""
+
     def format(self, match: "MatchError") -> str:
         _id = getattr(match.rule, "id", "000")
         result = f"[error_code]{_id}[/][dim]:[/] [error_title]{self.escape(match.message)}[/]"
         if match.tag:
-            result += f" [dim][error_code]({match.tag})[/][/]"
+            result += f" [dim][error_code]({self.escape(match.tag)})[/][/]"
         result += (
             "\n"
             f"[filename]{self._format_path(match.filename or '')}[/]:{match.position}"
@@ -73,6 +71,8 @@ class Formatter(BaseFormatter):  # type: ignore
 
 
 class QuietFormatter(BaseFormatter[Any]):
+    """Brief output formatter for ansible-lint."""
+
     def format(self, match: "MatchError") -> str:
         return (
             f"[error_code]{match.rule.id}[/] "
@@ -90,10 +90,10 @@ class ParseableFormatter(BaseFormatter[Any]):
         )
 
         if not options.quiet:
-            result += f" [dim]{match.message}[/]"
+            result += f": [dim]{match.message}[/]"
 
         if match.tag:
-            result += f" [dim][error_code]({match.tag})[/][/]"
+            result += f" [dim][error_code]({self.escape(match.tag)})[/][/]"
         return result
 
 
@@ -139,21 +139,6 @@ class AnnotationsFormatter(BaseFormatter):  # type: ignore
         return "error"
 
 
-class ParseableSeverityFormatter(BaseFormatter[Any]):
-    def format(self, match: "MatchError") -> str:
-
-        filename = self._format_path(match.filename or "")
-        position = match.position
-        rule_id = "{0}".format(match.rule.id)
-        severity = match.rule.severity
-        message = self.escape(str(match.message))
-
-        return (
-            f"[filename]{filename}[/]:{position}: [[error_code]{rule_id}[/]] "
-            f"[[error_code]{severity}[/]] [dim]{message}[/]"
-        )
-
-
 class CodeclimateJSONFormatter(BaseFormatter[Any]):
     """Formatter for emitting violations in Codeclimate JSON report format.
 
@@ -163,10 +148,10 @@ class CodeclimateJSONFormatter(BaseFormatter[Any]):
     """
 
     def format_result(self, matches: List["MatchError"]) -> str:
-
+        """Format a list of match errors as a JSON string."""
         if not isinstance(matches, list):
             raise RuntimeError(
-                "The CodeclimatJSONFormatter was expecting a list of MatchError."
+                f"The {self.__class__} was expecting a list of MatchError."
             )
 
         result = []
@@ -209,3 +194,127 @@ class CodeclimateJSONFormatter(BaseFormatter[Any]):
             return "blocker"
         # VERY_LOW, INFO or anything else
         return "info"
+
+
+class SarifFormatter(BaseFormatter[Any]):
+    """Formatter for emitting violations in SARIF report format.
+
+    The spec of SARIF can be found here:
+    https://docs.oasis-open.org/sarif/sarif/v2.1.0/
+    """
+
+    BASE_URI_ID = "SRCROOT"
+    TOOL_NAME = "Ansible-lint"
+    TOOL_URL = "https://github.com/ansible/ansible-lint"
+    SARIF_SCHEMA_VERSION = "2.1.0"
+    RULE_DOC_URL = "https://ansible-lint.readthedocs.io/en/latest/default_rules/"
+    SARIF_SCHEMA = (
+        "https://schemastore.azurewebsites.net/schemas/json/sarif-2.1.0-rtm.5.json"
+    )
+
+    def format_result(self, matches: List["MatchError"]) -> str:
+        """Format a list of match errors as a JSON string."""
+        if not isinstance(matches, list):
+            raise RuntimeError(
+                f"The {self.__class__} was expecting a list of MatchError."
+            )
+
+        root_path = Path(str(self._base_dir)).as_uri()
+        root_path = root_path + "/" if not root_path.endswith("/") else root_path
+        rules, results = self._extract_results(matches)
+
+        tool = {
+            "driver": {
+                "name": self.TOOL_NAME,
+                "version": __version__,
+                "informationUri": self.TOOL_URL,
+                "rules": rules,
+            }
+        }
+
+        runs = [
+            {
+                "tool": tool,
+                "columnKind": "utf16CodeUnits",
+                "results": results,
+                "originalUriBaseIds": {
+                    self.BASE_URI_ID: {"uri": root_path},
+                },
+            }
+        ]
+
+        report = {
+            "$schema": self.SARIF_SCHEMA,
+            "version": self.SARIF_SCHEMA_VERSION,
+            "runs": runs,
+        }
+
+        return json.dumps(
+            report, default=lambda o: o.__dict__, sort_keys=False, indent=2
+        )
+
+    def _extract_results(
+        self, matches: List["MatchError"]
+    ) -> Tuple[List[Any], List[Any]]:
+        rules = {}
+        results = []
+        for match in matches:
+            if match.rule.id not in rules:
+                rules[match.rule.id] = self._to_sarif_rule(match)
+            results.append(self._to_sarif_result(match))
+        return list(rules.values()), results
+
+    def _to_sarif_rule(self, match: "MatchError") -> Dict[str, Any]:
+        rule: Dict[str, Any] = {
+            "id": match.rule.id,
+            "name": match.rule.id,
+            "shortDescription": {
+                "text": self.escape(str(match.message)),
+            },
+            "defaultConfiguration": {
+                "level": self._to_sarif_level(match.rule.severity),
+            },
+            "help": {
+                "text": str(match.rule.description),
+            },
+            "helpUri": self.RULE_DOC_URL + "#" + match.rule.id,
+            "properties": {"tags": match.rule.tags},
+        }
+        if match.rule.link:
+            rule["helpUri"] = match.rule.link
+        return rule
+
+    def _to_sarif_result(self, match: "MatchError") -> Dict[str, Any]:
+        result: Dict[str, Any] = {
+            "ruleId": match.rule.id,
+            "message": {
+                "text": match.details,
+            },
+            "locations": [
+                {
+                    "physicalLocation": {
+                        "artifactLocation": {
+                            "uri": self._format_path(match.filename or ""),
+                            "uriBaseId": self.BASE_URI_ID,
+                        },
+                        "region": {
+                            "startLine": match.linenumber,
+                        },
+                    },
+                },
+            ],
+        }
+        if match.column:
+            result["locations"][0]["physicalLocation"]["region"][
+                "startColumn"
+            ] = match.column
+        return result
+
+    @staticmethod
+    def _to_sarif_level(severity: str) -> str:
+        if severity in ["VERY_HIGH", "HIGH", "MEDIUM"]:
+            return "error"
+        if severity in ["LOW"]:
+            return "warning"
+        # VERY_LOW, INFO or anything else
+        return "note"
