@@ -188,7 +188,7 @@ def find_children(lintable: Lintable) -> List[Lintable]:  # noqa: C901
         try:
             playbook_ds = parse_yaml_from_file(str(lintable.path))
         except AnsibleError as exc:
-            raise SystemExit from exc
+            raise SystemExit(exc) from exc
     results = []
     basedir = os.path.dirname(str(lintable.path))
     # playbook_ds can be an AnsibleUnicode string, which we consider invalid
@@ -334,9 +334,14 @@ def _taskshandlers_children(
             results.append(children)
             continue
 
-        if (
-            "include_role" in task_handler or "import_role" in task_handler
-        ):  # lgtm [py/unreachable-statement]
+        including_commands = (
+            "import_role",
+            "ansible.builtin.import_role",
+            "include_role",
+            "ansible.builtin.include_role",
+        )
+        if any(x in task_handler for x in including_commands):
+            # lgtm [py/unreachable-statement]
             task_handler = normalize_task_v2(task_handler)
             _validate_task_handler_action_for_role(task_handler["action"])
             results.extend(
@@ -516,12 +521,39 @@ def _sanitize_task(task: Dict[str, Any]) -> Dict[str, Any]:
     return result
 
 
+def _extract_ansible_parsed_keys_from_task(
+    result: Dict[str, Any],
+    task: Dict[str, Any],
+    keys: Tuple[str, ...],
+) -> Dict[str, Any]:
+    """Return a dict with existing key in task."""
+    for (k, v) in list(task.items()):
+        if k in keys:
+            # we don't want to re-assign these values, which were
+            # determined by the ModuleArgsParser() above
+            continue
+        result[k] = v
+    return result
+
+
 def normalize_task_v2(task: Dict[str, Any]) -> Dict[str, Any]:
     """Ensure tasks have a normalized action key and strings are converted to python objects."""
-    result = {}
+    result: Dict[str, Any] = {}
+    ansible_parsed_keys = ("action", "local_action", "args", "delegate_to")
+
+    if is_nested_task(task):
+        _extract_ansible_parsed_keys_from_task(result, task, ansible_parsed_keys)
+        # Add dummy action for block/always/rescue statements
+        result["action"] = dict(
+            __ansible_module__="block/always/rescue",
+            __ansible_module_original__="block/always/rescue",
+        )
+
+        return result
 
     sanitized_task = _sanitize_task(task)
     mod_arg_parser = ModuleArgsParser(sanitized_task)
+
     try:
         action, arguments, result["delegate_to"] = mod_arg_parser.parse(
             skip_action_validation=options.skip_action_validation
@@ -540,12 +572,9 @@ def normalize_task_v2(task: Dict[str, Any]) -> Dict[str, Any]:
         action = "shell"
         del arguments["_uses_shell"]
 
-    for (k, v) in list(task.items()):
-        if k in ("action", "local_action", "args", "delegate_to") or k == action:
-            # we don't want to re-assign these values, which were
-            # determined by the ModuleArgsParser() above
-            continue
-        result[k] = v
+    _extract_ansible_parsed_keys_from_task(
+        result, task, ansible_parsed_keys + (action,)
+    )
 
     if not isinstance(action, str):
         raise RuntimeError(f"Task actions can only be strings, got {action}")
@@ -655,8 +684,6 @@ def get_action_tasks(data: AnsibleBaseYAMLObject, file: Lintable) -> List[Any]:
 
     # Add sub-elements of block/rescue/always to tasks list
     tasks.extend(extract_from_list(tasks, NESTED_TASK_KEYS, recursive=True))
-    # Remove block/rescue/always elements from tasks list
-    tasks[:] = [task for task in tasks if all(k not in task for k in NESTED_TASK_KEYS)]
 
     # Include the FQCN task names as this happens before normalize
     return [
@@ -870,3 +897,12 @@ def nested_items(
             yield "list-item", item, parent
             for k, v, returned_parent in nested_items(item):
                 yield k, v, returned_parent
+
+
+def is_nested_task(task: Dict[str, Any]) -> bool:
+    """Check if task includes block/always/rescue."""
+    for key in NESTED_TASK_KEYS:
+        if task.get(key):
+            return True
+
+    return False
